@@ -4,36 +4,29 @@ The main DebugToolbar class that loads and renders the Toolbar.
 
 from __future__ import absolute_import, unicode_literals
 
-try:
-    from importlib import import_module
-except ImportError:  # python 2.6
-    from django.utils.importlib import import_module
 import uuid
+from collections import OrderedDict
 
-import django
-from django.conf import settings
+from django.apps import apps
 from django.conf.urls import url
 from django.core.exceptions import ImproperlyConfigured
 from django.template import TemplateSyntaxError
 from django.template.loader import render_to_string
-try:
-    from collections import OrderedDict
-except ImportError:
-    from django.utils.datastructures import SortedDict as OrderedDict
+from django.utils.module_loading import import_string
 
 from debug_toolbar import settings as dt_settings
 
 
 class DebugToolbar(object):
-
     def __init__(self, request):
         self.request = request
-        self.config = dt_settings.CONFIG.copy()
+        self.config = dt_settings.get_config().copy()
         self._panels = OrderedDict()
         for panel_class in self.get_panel_classes():
             panel_instance = panel_class(self)
             self._panels[panel_instance.panel_id] = panel_instance
         self.stats = {}
+        self.server_timing_stats = {}
         self.store_id = None
 
     # Manage panels
@@ -67,21 +60,15 @@ class DebugToolbar(object):
         if not self.should_render_panels():
             self.store()
         try:
-            context = {'toolbar': self}
-            return render_to_string('debug_toolbar/base.html', context)
+            context = {"toolbar": self}
+            return render_to_string("debug_toolbar/base.html", context)
         except TemplateSyntaxError:
-            if django.VERSION[:2] >= (1, 7):
-                from django.apps import apps
-                staticfiles_installed = apps.is_installed(
-                    'django.contrib.staticfiles')
-            else:
-                staticfiles_installed = ('django.contrib.staticfiles'
-                                         in settings.INSTALLED_APPS)
-            if not staticfiles_installed:
+            if not apps.is_installed("django.contrib.staticfiles"):
                 raise ImproperlyConfigured(
                     "The debug toolbar requires the staticfiles contrib app. "
                     "Add 'django.contrib.staticfiles' to INSTALLED_APPS and "
-                    "define STATIC_URL in your settings.")
+                    "define STATIC_URL in your settings."
+                )
             else:
                 raise
 
@@ -90,18 +77,16 @@ class DebugToolbar(object):
     _store = OrderedDict()
 
     def should_render_panels(self):
-        render_panels = self.config['RENDER_PANELS']
+        render_panels = self.config["RENDER_PANELS"]
         if render_panels is None:
-            # Django 1.4 still supports mod_python :( Fall back to the safe
-            # and inefficient default in that case. Revert when we drop 1.4.
-            render_panels = self.request.META.get('wsgi.multiprocess', True)
+            render_panels = self.request.META["wsgi.multiprocess"]
         return render_panels
 
     def store(self):
         self.store_id = uuid.uuid4().hex
         cls = type(self)
         cls._store[self.store_id] = self
-        for _ in range(len(cls._store) - self.config['RESULTS_STORE_SIZE']):
+        for _ in range(len(cls._store) - self.config["RESULTS_CACHE_SIZE"]):
             try:
                 # collections.OrderedDict
                 cls._store.popitem(last=False)
@@ -122,27 +107,9 @@ class DebugToolbar(object):
     def get_panel_classes(cls):
         if cls._panel_classes is None:
             # Load panels in a temporary variable for thread safety.
-            panel_classes = []
-            for panel_path in dt_settings.PANELS:
-                # This logic could be replaced with import_by_path in Django 1.6.
-                try:
-                    panel_module, panel_classname = panel_path.rsplit('.', 1)
-                except ValueError:
-                    raise ImproperlyConfigured(
-                        "%s isn't a debug panel module" % panel_path)
-                try:
-                    mod = import_module(panel_module)
-                except ImportError as e:
-                    raise ImproperlyConfigured(
-                        'Error importing debug panel %s: "%s"' %
-                        (panel_module, e))
-                try:
-                    panel_class = getattr(mod, panel_classname)
-                except AttributeError:
-                    raise ImproperlyConfigured(
-                        'Toolbar Panel module "%s" does not define a "%s" class' %
-                        (panel_module, panel_classname))
-                panel_classes.append(panel_class)
+            panel_classes = [
+                import_string(panel_path) for panel_path in dt_settings.get_panels()
+            ]
             cls._panel_classes = panel_classes
         return cls._panel_classes
 
@@ -152,10 +119,11 @@ class DebugToolbar(object):
     def get_urls(cls):
         if cls._urlpatterns is None:
             from . import views
+
             # Load URLs in a temporary variable for thread safety.
             # Global URLs
             urlpatterns = [
-                url(r'^render_panel/$', views.render_panel, name='render_panel'),
+                url(r"^render_panel/$", views.render_panel, name="render_panel")
             ]
             # Per-panel URLs
             for panel_class in cls.get_panel_classes():
@@ -164,4 +132,5 @@ class DebugToolbar(object):
         return cls._urlpatterns
 
 
+app_name = "djdt"
 urlpatterns = DebugToolbar.get_urls()
